a list containing control arguments for the step length of the N values(step, default value depending on the estimate of N), range of N values in terms of distance of the log-likelhood from the its maximum (mult, default value 1.5), and maximum value of this grid as a multiple of the estimate of this parameter (max, default value 5)
level
the confidence level required
...
additional argument(s) for methods
Author
Francesco Bartolucci, Antonio Forcina
References
Forcina, A. and Bartolucci, F. (2021). Estimating the size of a closed population by modeling latent and observed heterogeneity, arXiv:2106.03811.
Liu, Y., Li, P., and Qin, J. (2017). Maximum empirical likelihood estimation for abundance in a closed population from capture-recapture data. Biometrika, 104, 527-543.